# Data Processing Toolkit

Комплексное решение для обработки и анализа данных, включающее:
- 🖥️ **Графическое приложение** (PyQt5)
- 🌐 **Веб-сервис** (FastAPI)
- 📊 **Автоматизированную аналитику** (ydata-profiling)

![Architecture Diagram](BPMN_DPro.pdf) *(Схема взаимодействия компонентов)*


## 🌟 Основные возможности графического приложения (PyQt5)

### 🔢 Обработка табличных данных:
- Загрузка данных из CSV, Excel, JSON, Parquet
- Удаление дубликатов
- Обработка пропущенных значений (замена средним, медианой, константой)
- Обнаружение и удаление выбросов (методы IQR, Hampel и др.)
- Масштабирование данных (нормализация MinMax, стандартизация Z-score)
- Визуализация (гистограммы, boxplot, scatter-plot и др.)
- Автоматический анализ данных

### 📖 Обработка текстовых данных:
- Удаление HTML-тегов и спецсимволов
- Токенизация (по словам/предложениям)
- Удаление стоп-слов
- Нормализация (стемминг, лемматизация)
- Анализ текста с рекомендациями
- Поддержка русского и английского языков
- Обработка для NLP-задач (анализ тональности, суммаризация и др.)


## 🌟 Основные возможности веб-сервиса (FastAPI)

- REST API для обработки данных
- Генерация автоматических отчетов (ydata-profiling)
- Интерактивный интерфейс через Jupyter-подобный ноутбук
- Загрузка файлов через веб-интерфейс

**Ключевые эндпоинты:**
| Метод | Путь | Описание |
|-------|------|----------|
| GET | `/` | Веб-интерфейс ноутбука |
| POST | `/uploadfile/` | Загрузка файлов (CSV/XLSX) |
| GET | `/DataFrame/` | Обработка данных по ID метода |
| POST | `/generate_report/` | Генерация HTML-отчета |


## 🛠️ Технологический стек

**Backend:**
- Python 3.10+
- FastAPI (веб-сервис)
- Uvicorn (ASGI-сервер)
- Pandas (обработка данных)
- ydata-profiling (анализ данных)

**Графическое приложение:**
- PyQt5
- Matplotlib
- NLTK/spaCy


## ⚙️ Установка и запуск

### Для приложения:

   ```bash
   # Клонировать репозиторий
   git clone https://github.com/Balots/DPro.git

  # Перейти в папку с репозиторием
   cd DPro

  # Установить зависисмости
   pip install -r requirements.txt

  # Запуск приложения
   python app.py

  # Запуск веб-сервиса
   python main.py
   ```

## 📌 Пример использования

[ЗАПИСЬ1.mov](https://github.com/Balots/DPro/blob/main/ЗАПИСЬ1.mov)

[ЗАПИСЬ2.mov](https://github.com/Balots/DPro/blob/main/ЗАПИСЬ2.mov)
